@@ -4,13 +4,23 @@ use strict;
 use warnings;
 use Text::Pipe::Base;   # for def_pipe()
 use Sub::Name;
-
-
-our $VERSION = '0.01';
-
-
 use UNIVERSAL::require;
 
+
+our $VERSION = '0.02';
+
+
+use base 'Exporter';
+
+
+our %EXPORT_TAGS = (
+    util  => [ qw(pipe) ],
+);
+
+
+our @EXPORT_OK = @{ $EXPORT_TAGS{all} = [ map { @$_ } values %EXPORT_TAGS ] };
+
+
 # this is just a factory
 
 sub new {
@@ -38,6 +48,14 @@ sub def_pipe {
 }
 
 
+# Easier, procedural, way to construct a pipe
+
+sub pipe {
+    my ($type, @args) = @_;
+    Text::Pipe->new($type, @args);
+}
+
+
 1;
 
 
